package InitialSchedules;

import org.chocosolver.solver.Solution;

public class InitialSchedulesArray {

    private int[][] PartTimeSchedules;
    private int[][] FullTimeSchedules;
    private int maxPartTimeEmployee;
    private int maxFullTimeEmployee;
    private int workPeriodsPerSchedule;
    private ModelInitialSchedules myModelInitialSchedules;

    public InitialSchedulesArray(ModelInitialSchedules m, Solution s) {
        this.myModelInitialSchedules = m;
        Solution mySolution = s;
        this.maxPartTimeEmployee = myModelInitialSchedules.maxPartTimeEmployee;
        this.maxFullTimeEmployee = myModelInitialSchedules.maxFullTimeEmployee;
        this.workPeriodsPerSchedule = myModelInitialSchedules.myScheduleParameters.workPeriodsPerSchedule;

        this.PartTimeSchedules = new int[this.maxPartTimeEmployee][this.workPeriodsPerSchedule];
        this.FullTimeSchedules = new int[this.maxFullTimeEmployee][this.workPeriodsPerSchedule];
        for (int workPeriod = 0; workPeriod < this.workPeriodsPerSchedule; workPeriod++) {
            for (int employee = 0; employee < this.maxPartTimeEmployee; employee++) {
                this.PartTimeSchedules[employee][workPeriod] = mySolution.getIntVal(myModelInitialSchedules.workPeriodsSchedulesOfPartTimeEmployees[employee][workPeriod]);
            }
        }

        for (int workPeriod = 0; workPeriod < this.workPeriodsPerSchedule; workPeriod++) {
            for (int employee = 0; employee < this.maxFullTimeEmployee; employee++) {
                this.FullTimeSchedules[employee][workPeriod] = mySolution.getIntVal(myModelInitialSchedules.workPeriodsSchedulesOfFullTimeEmployees[employee][workPeriod]);
            }
        }
    }

    public int getMaxFullTimeEmployee() {
        return maxFullTimeEmployee;
    }

    public int getMaxPartTimeEmployee() {
        return maxPartTimeEmployee;
    }

    public int getWorkPeriodsPerSchedule() {
        return workPeriodsPerSchedule;
    }

    public int[][] getFullTimeSchedules() {
        return FullTimeSchedules;
    }

    public int[][] getPartTimeSchedules() {
        return PartTimeSchedules;
    }
}
